==> singularity-container_2.3.2.orig.tar.gz: singularity-2.3.2/.github/SUPPORT.md <==
# Singularity Support

Need help? We have several ways to reach us, depending on your preferences and needs.

## Documentation
If you haven't already, search our [user quick start](http://singularity.lbl.gov/quickstart), [docs base](http://singularity.lbl.gov/docs-quick-start-installation), and [other guides](http://singularity.lbl.gov/links) from the community. These docs have common use cases, and might be helpful to browse before submitting an issue. If you have a good resource, please [let us know](https://github.com/singularityware/singularity/issues).


## Github
For issues with code (and especially if you need to share debug output) we recommend Github issues boards.

 - [Singularity Issues](https://github.com/singularityware/singularity/issues): is recommended for most issues with the Singularity software.
 - [Singularity Hub Issues](https://github.com/singularityhub/singularityhub.github.io/issues): is the board for issues relevant to Singularity Hub.
 - [Documentation Issues](https://github.com/singularityware/singularityware.github.io/issues): documentation questions, feedback, and suggestions should go here. Feel free to create an issue on a board and additionally request updated content here.

## Google Group
You can reach the community quickly by way of joining our [Google Group](https://groups.google.com/a/lbl.gov/forum/#!forum/singularity).

## Slack
For real time support from the community, you can join our community on slack at [https://singularity-container.slack.com/](https://singularity-container.slack.com/). Ping the Google Group or one of the admins here to request to be added.

Is there something missing here you'd like to see? Please [let us know](https://github.com/singularityware/singularity/issues).

==> singularity-container_2.4.2.orig.tar.gz: singularity-2.4.2/.github/SUPPORT.md <==
# Singularity Support

Need help? We have several ways to reach us, depending on your preferences and needs.

## Documentation
If you haven't already, search our [user quick start](http://singularity.lbl.gov/quickstart), [docs base](http://singularity.lbl.gov/docs-quick-start-installation), and [other guides](http://singularity.lbl.gov/links) from the community. These docs have common use cases, and might be helpful to browse before submitting an issue. If you have a good resource, please [let us know](https://github.com/singularityware/singularity/issues).


## Github
For issues with code (and especially if you need to share debug output) we recommend Github issues boards.

 - [Singularity Issues](https://github.com/singularityware/singularity/issues): is recommended for most issues with the Singularity software.
 - [Singularity Hub Issues](https://github.com/singularityhub/singularityhub.github.io/issues): is the board for issues relevant to Singularity Hub.
 - [Singularity Registry Issues](https://github.com/singularityhub/sregistry/issues): is the board for issues relevant to Singularity Registry
 - [Documentation Issues](https://github.com/singularityware/singularityware.github.io/issues): documentation questions, feedback, and suggestions should go here. Feel free to create an issue on a board and additionally request updated content here.

## Google Group
You can reach the community quickly by way of joining our [Google Group](https://groups.google.com/a/lbl.gov/forum/#!forum/singularity).

## Slack
For real time support from the community, you can join our community on slack at [https://singularity-container.slack.com/](https://singularity-container.slack.com/). Ping the Google Group or one of the admins here to request to be added.

Is there something missing here you'd like to see? Please [let us know](https://github.com/singularityware/singularity/issues).
